django-tabination
=================

django-tabination is a lightweight library that enables you to easily build your own tab navigation based on class based views.

Docs
----

The docs can be found at http://django-tabination.readthedocs.org/.

Changelog
---------

v0.1.1 (2012-05-04)

- [add] Added `current_tab_id` to context by default

v0.1.0 (2012-04-04)

- [add] Initial version

License
-------

Copyright 2012 Factor AG (http://factor.ch/)

This program is free software: you can redistribute it and/or modify it under the terms of the GNU
Lesser General Public License as published by the Free Software Foundation, either version 3 of the
License, or any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program.
If not, see http://www.gnu.org/licenses/lgpl.html.
